==> _private_core_network-1.2.79.tar.gz: lib/network_resources/common/models/contact_form_fields.dart <==

class ContactFormField {
  int? id;
  String? label;
  int? platformId;
  int? organisationId;
  String? notificationToEmail;
  List<FormFields>? formFields;

  ContactFormField({this.id, this.label, this.platformId, this.organisationId, this.notificationToEmail, this.formFields});

  ContactFormField.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    label = json["label"];
    platformId = json["platformId"];
    organisationId = json["organisationId"];
    notificationToEmail = json["notificationToEmail"];
    formFields = json["formFields"] == null ? null : (json["formFields"] as List).map((e) => FormFields.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    _data["platformId"] = platformId;
    _data["organisationId"] = organisationId;
    _data["notificationToEmail"] = notificationToEmail;
    if(formFields != null) {
      _data["formFields"] = formFields?.map((e) => e.toJson()).toList();
    }
    return _data;
  }
}

class FormFields {
  int? id;
  int? formId;
  int? order;
  String? label;
  String? type;
  int? isRequired;

  FormFields({this.id, this.formId, this.order, this.label, this.type, this.isRequired});

  FormFields.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    formId = json["formId"];
    order = json["order"];
    label = json["label"];
    type = json["type"];
    isRequired = json["isRequired"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["formId"] = formId;
    _data["order"] = order;
    _data["label"] = label;
    _data["type"] = type;
    _data["isRequired"] = isRequired;
    return _data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/common/models/contact_form_fields.dart <==

class ContactFormField {
  int? id;
  String? label;
  int? platformId;
  int? organisationId;
  String? notificationToEmail;
  List<FormFields>? formFields;

  ContactFormField({this.id, this.label, this.platformId, this.organisationId, this.notificationToEmail, this.formFields});

  ContactFormField.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    label = json["label"];
    platformId = json["platformId"];
    organisationId = json["organisationId"];
    notificationToEmail = json["notificationToEmail"];
    formFields = json["formFields"] == null ? null : (json["formFields"] as List).map((e) => FormFields.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["label"] = label;
    data["platformId"] = platformId;
    data["organisationId"] = organisationId;
    data["notificationToEmail"] = notificationToEmail;
    if(formFields != null) {
      data["formFields"] = formFields?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class FormFields {
  int? id;
  int? formId;
  int? order;
  String? label;
  String? type;
  int? isRequired;

  FormFields({this.id, this.formId, this.order, this.label, this.type, this.isRequired});

  FormFields.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    formId = json["formId"];
    order = json["order"];
    label = json["label"];
    type = json["type"];
    isRequired = json["isRequired"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["formId"] = formId;
    data["order"] = order;
    data["label"] = label;
    data["type"] = type;
    data["isRequired"] = isRequired;
    return data;
  }
}
